@@ -37,7 +37,7 @@ class SensorConfig(Mapping):
 
     # override required Mapping functions
     def __iter__(self):
-        for k, v in self.__dict__.items():
+        for k, v in {k: v for k,v in self.__dict__.items() if v}.items():
             yield k
 
     def __len__(self):
@@ -65,8 +65,19 @@ class Conf:
     log_level: str
     sensors: list
 
+    def update_sensor(self, sensor):
+        _sensor = list(filter(lambda s: s.name == sensor.name, self.sensors))[0]
+        _keys = list(filter(lambda k: not(k.startswith('_')), _sensor.__dict__.keys()))
+        _config = {k: v for k, v in _sensor.__dict__.items() if k in _keys}
+        _sensor = SensorConfig(**_config)
+
     def to_dict(self):
-        return asdict(self)
+        _cfg = asdict(self)
+        sensors = []
+        for sensor in _cfg['sensors']:
+            sensors.append({k:v for k,v in sensor.items() if v})
+        _cfg['sensors'] = sensors
+        return _cfg
 
 
 class Config():
@@ -119,8 +130,12 @@ class Config():
         logger = logging.getLogger().setLevel(_level)
 
     @classmethod
-    def save(cls):
+    def save(cls, **kwargs):
+        if kwargs.get('sensor'):
+            cls._config.update_sensor(kwargs.get('sensor'))
+            
         logging.info("Saving config file...")
+        logging.debug(cls._config.to_dict())
         with open(cls._filename, 'w') as f:
             yaml.dump(cls._config.to_dict(), f)
 
